﻿using System;

using DevExpress.XtraEditors;
using DevExpress.XtraTreeList;
using DevExpress.XtraTreeList.Nodes;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                         += Form_Load;
            this.treeList.GetSelectImage += treeList_GetSelectImage;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.treeList.RowHeight                              = 25;
            this.treeList.OptionsView.AutoWidth                  = false;
            this.treeList.OptionsBehavior.ReadOnly               = true;
            this.treeList.OptionsBehavior.PopulateServiceColumns = true;
            this.treeList.KeyFieldName                           = "ID";
            this.treeList.ParentFieldName                        = "RegionID";
            this.treeList.SelectImageList                        = this.svgImageCollection;

            this.treeList.DataSource = SalesData.GetSalesDataList();

            this.treeList.Columns[this.treeList.KeyFieldName   ].Visible = false;
            this.treeList.Columns[this.treeList.ParentFieldName].Visible = false;

            SetNodeImage(this.treeList.Nodes);

            this.treeList.BestFitColumns();

            this.treeList.ExpandAll();
        }

        #endregion
        #region 트리 리스트 선택 이미지 구하기 - treeList_GetSelectImage(sender, e)

        /// <summary>
        /// 트리 리스트 선택 이미지 구하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_GetSelectImage(object sender, GetSelectImageEventArgs e)
        {
            if(e.FocusedNode)
            {
                e.NodeImageIndex = 2;
            }
            else
            {
                e.NodeImageIndex = 0;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 노드 이미지 설정하기 - SetNodeImage(nodes)

        /// <summary>
        /// 노드 이미지 설정하기
        /// </summary>
        /// <param name="nodes">노드</param>
        private void SetNodeImage(TreeListNodes nodes)
        {
            if(nodes.Count == 0)
            {
                return;
            }

            foreach(TreeListNode node in nodes)
            {
                node.ImageIndex = 0;

                SetNodeImage(node.Nodes);
            }
        }

        #endregion
    }
}